@@ -3,8 +3,7 @@ from UniTok.vocab.vocab import Vocab
 
 
 class EntTok(BaseTok):
-    def __init__(self, name, vocab: Vocab = None):
-        super(EntTok, self).__init__(name=name, vocab=vocab)
-
     def t(self, obj):
+        if self.pre_handler:
+            obj = self.pre_handler(obj)
         return self.vocab.append(str(obj))
