@@ -2,8 +2,7 @@ from .tok import BaseTok
 
 
 class IdTok(BaseTok):
-    def __init__(self, name):
-        super(IdTok, self).__init__(name=name)
-
     def t(self, obj):
+        if self.pre_handler:
+            obj = self.pre_handler(obj)
         return self.vocab.append(str(obj))
