@@ -5,8 +5,8 @@ from UniTok.vocab.vocab import Vocab
 
 
 class SplitTok(BaseTok):
-    def __init__(self, name, sep, vocab: Vocab = None):
-        super(SplitTok, self).__init__(name=name, vocab=vocab)
+    def __init__(self, name, sep, **kwargs):
+        super(SplitTok, self).__init__(name=name, **kwargs)
         self.sep = sep
 
     def t(self, obj,):
@@ -14,5 +14,7 @@ class SplitTok(BaseTok):
         if pd.notnull(obj):
             ts = obj.split(self.sep)
             for t in ts:
+                if self.pre_handler:
+                    t = self.pre_handler(t)
                 ids.append(self.vocab.append(t))
         return ids
